# Entropy Labs Python Package


## Sentinel
Sentinel is an agent control plane developed by Entropy Labs that allows you to efficiently oversee thousands of agents running in parallel. This is the Python package for Sentinel, which implements various types of approvers that can be integrated into the AISI Inspect platform or used separately.

### Features

- Efficient oversight of parallel-running agents
- Various types of approvers including human, bash, python or LLM-powered approvers
- Integration with AISI's Inspect platform
- Standalone usage capability

### More Information

For more detailed information, documentation, and usage examples, please visit the main GitHub repository:

[https://github.com/EntropyLabsAI/sentinel](https://github.com/EntropyLabsAI/sentinel)


